@@ -13,9 +13,7 @@
 # limitations under the License.
 
 from dataclasses import dataclass
-from datetime import datetime
-from enum import Enum
-from typing import List, Optional
+from typing import List
 
 from rpe.resources.base import Resource
 
