@@ -13,30 +13,28 @@
 # limitations under the License.
 
 
-from .engines import OpenPolicyAgent
-from .engines import PythonPolicyEngine
+from .engines import OpenPolicyAgent, PythonPolicyEngine
 
 
 class RPE:
-
     def __init__(self, config):
         self.policy_engines = []
 
-        for pe_config in config['policy_engines']:
+        for pe_config in config["policy_engines"]:
             self._add_policy_engine(pe_config)
 
     def _add_policy_engine(self, pe_config):
-        if pe_config.get('type') == 'opa':
-            engine = OpenPolicyAgent(pe_config['url'])
-        elif pe_config.get('type') == 'python':
-            engine = PythonPolicyEngine(pe_config['path'])
+        if pe_config.get("type") == "opa":
+            engine = OpenPolicyAgent(pe_config["url"])
+        elif pe_config.get("type") == "python":
+            engine = PythonPolicyEngine(pe_config["path"])
         else:
             raise AttributeError("Unrecognized policy engine configuration")
 
         self.policy_engines.append(engine)
 
     def evaluate(self, resource):
-        '''Get all policies that apply to the given resource'''
+        """Get all policies that apply to the given resource"""
         evaluations = []
         for pe in self.policy_engines:
             evaluations.extend(pe.evaluate(resource))
@@ -44,7 +42,7 @@ class RPE:
         return evaluations
 
     def policies(self):
-        '''Get all configured policies'''
+        """Get all configured policies"""
         policies = []
         for pe in self.policy_engines:
             policies.extend(pe.policies())
